data(ecoli.m52.genome)
data(ecoligenomeCHRLOC)
data(ecoligenomeSYMBOL2AFFY)
data(ecoligenomeSYMBOL)
data(ecoligenomeSTRAND)
data(ecoligenome.operon)
ecoli.lenecoli.m52.genome is character
with genome sequence.
The format for ecoligenomeCHRLOC is
an environment (as a hash table). Each key
is an Affyemtrix probe set ID, and each value is vector of
two integers (begining and end - see the details
below)
The format for ecoligenomeSYMBOL2AFFFY
is an environment (as a hash table). Each key is
a gene symbol name.
The format for ecoligenomeSYMBOL
is an environment (as a hash table). Each key
is an Affymetrix probe set id
ecoli.len is a variable containing the size of the genome in
ecoli.m52.genome.ecoligenomeSYMBOL2AFFFY and
ecoligenomeSYMBOL are like the ones in the
data packages built by annBuilder.
The environment
ecoligenomeCHRLOC differs: two integers are associated
with each key, one corresponds to the begining of the segment
the other to the end. The environment ecoligenomeSTRAND returns a logical.
TRUE means that the orientation is `+', FALSE means
that the orientation is '-' (and NA is used when irrelevant
for the key).