library(Biobase)
data(ecoligenome.operon)
data(ecoligenomeSYMBOL2AFFY)
## something that might be useful when working with Affymetrix data:
## get the Affymetrix identifiers for the probe sets bundled in operons
## (see the vignette for more details)
ecoligenome.operon$affyid <-
unname(unlist(mget(ecoligenome.operon$gene.name,
ecoligenomeSYMBOL2AFFY, ifnotfound=NA)))
Run the code above in your browser using DataLab